==> qownnotes-debug-24.11.0-1-x86_64.pkg.tar.zst: usr/src/debug/qownnotes/qownnotes-24.11.0/qrc_texts.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.15
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/qownnotes/src/qownnotes-24.11.0/html/about.html
  0x0,0x0,0x4,0x2a,
  0x3c,
  0x21,0x44,0x4f,0x43,0x54,0x59,0x50,0x45,0x20,0x48,0x54,0x4d,0x4c,0x20,0x50,0x55,
  0x42,0x4c,0x49,0x43,0x20,0x22,0x2d,0x2f,0x2f,0x57,0x33,0x43,0x2f,0x2f,0x44,0x54,
  0x44,0x20,0x48,0x54,0x4d,0x4c,0x20,0x34,0x2e,0x30,0x2f,0x2f,0x45,0x4e,0x22,0x20,
  0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,
  0x72,0x67,0x2f,0x54,0x52,0x2f,0x52,0x45,0x43,0x2d,0x68,0x74,0x6d,0x6c,0x34,0x30,
  0x2f,0x73,0x74,0x72,0x69,0x63,0x74,0x2e,0x64,0x74,0x64,0x22,0x3e,0xa,0x3c,0x68,
  0x74,0x6d,0x6c,0x3e,0xa,0x3c,0x62,0x6f,0x64,0x79,0x3e,0xa,0x3c,0x70,0x3e,0x3c,
  0x73,0x74,0x72,0x6f,0x6e,0x67,0x3e,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,0x73,
  0x3c,0x2f,0x73,0x74,0x72,0x6f,0x6e,0x67,0x3e,0x20,0x2d,0x20,0x76,0x65,0x72,0x73,
  0x69,0x6f,0x6e,0x20,0x56,0x45,0x52,0x53,0x49,0x4f,0x4e,0x20,0x2d,0x20,0x52,0x45,
  0x4c,0x45,0x41,0x53,0x45,0x20,0x2d,0x20,0x62,0x75,0x69,0x6c,0x64,0x20,0x42,0x55,
  0x49,0x4c,0x44,0x5f,0x4e,0x55,0x4d,0x42,0x45,0x52,0x3c,0x2f,0x70,0x3e,0xa,0x3c,
  0x70,0x3e,0xa,0x20,0x20,0x20,0x20,0x50,0x6c,0x61,0x69,0x6e,0x2d,0x74,0x65,0x78,
  0x74,0x20,0x66,0x69,0x6c,0x65,0x20,0x6d,0x61,0x72,0x6b,0x64,0x6f,0x77,0x6e,0x20,
  0x6e,0x6f,0x74,0x65,0x20,0x74,0x61,0x6b,0x69,0x6e,0x67,0x20,0x77,0x69,0x74,0x68,
  0x20,0x4e,0x65,0x78,0x74,0x63,0x6c,0x6f,0x75,0x64,0x2f,0x6f,0x77,0x6e,0x43,0x6c,
  0x6f,0x75,0x64,0x20,0x69,0x6e,0x74,0x65,0x67,0x72,0x61,0x74,0x69,0x6f,0x6e,0x20,
  0x66,0x6f,0x72,0xa,0x20,0x20,0x20,0x20,0x47,0x4e,0x55,0x2f,0x4c,0x69,0x6e,0x75,
  0x78,0x2c,0x20,0x6d,0x61,0x63,0x4f,0x53,0x26,0x72,0x65,0x67,0x3b,0x20,0x61,0x6e,
  0x64,0x20,0x57,0x69,0x6e,0x64,0x6f,0x77,0x73,0x26,0x72,0x65,0x67,0x3b,0x20,0x28,
  0x69,0x74,0x20,0x69,0x73,0x20,0x77,0x72,0x69,0x74,0x74,0x65,0x6e,0x20,0x69,0x6e,
  0x20,0x43,0x2b,0x2b,0x2f,0x51,0x74,0x26,0x72,0x65,0x67,0x3b,0x29,0x2c,0xa,0x20,
  0x20,0x20,0x20,0x74,0x68,0x61,0x74,0x20,0x77,0x6f,0x72,0x6b,0x73,0x20,0x74,0x6f,
  0x67,0x65,0x74,0x68,0x65,0x72,0x20,0x77,0x69,0x74,0x68,0x20,0x74,0x68,0x65,0x20,
  0x6e,0x6f,0x74,0x65,0x73,0x20,0x61,0x70,0x70,0x6c,0x69,0x63,0x61,0x74,0x69,0x6f,
  0x6e,0x20,0x6f,0x66,0xa,0x20,0x20,0x20,0x20,0x3c,0x61,0x20,0x68,0x72,0x65,0x66,
  0x3d,0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x6e,0x65,0x78,0x74,0x63,0x6c,
  0x6f,0x75,0x64,0x2e,0x63,0x6f,0x6d,0x22,0x3e,0x4e,0x65,0x78,0x74,0x63,0x6c,0x6f,
  0x75,0x64,0x3c,0x2f,0x61,0x3e,0x20,0x61,0x6e,0x64,0xa,0x20,0x20,0x20,0x20,0x3c,
  0x61,0x20,0x68,0x72,0x65,0x66,0x3d,0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,
  0x6f,0x77,0x6e,0x63,0x6c,0x6f,0x75,0x64,0x2e,0x6f,0x72,0x67,0x22,0x3e,0x6f,0x77,
  0x6e,0x43,0x6c,0x6f,0x75,0x64,0x3c,0x2f,0x61,0x3e,0x2e,0xa,0x3c,0x2f,0x70,0x3e,
  0xa,0x3c,0x70,0x3e,0x42,0x75,0x69,0x6c,0x74,0x20,0x6f,0x6e,0x20,0x42,0x55,0x49,
  0x4c,0x44,0x5f,0x44,0x41,0x54,0x45,0x20,0x77,0x69,0x74,0x68,0x20,0x51,0x74,0x20,
  0x51,0x54,0x5f,0x56,0x45,0x52,0x53,0x49,0x4f,0x4e,0x5f,0x53,0x54,0x52,0x2e,0x3c,
  0x2f,0x70,0x3e,0xa,0x3c,0x70,0x3e,0x43,0x6f,0x70,0x79,0x72,0x69,0x67,0x68,0x74,
  0x20,0x32,0x30,0x31,0x34,0x2d,0x43,0x55,0x52,0x52,0x45,0x4e,0x54,0x5f,0x59,0x45,
  0x41,0x52,0x20,0x62,0x79,0x20,0x3c,0x61,0x20,0x68,0x72,0x65,0x66,0x3d,0x22,0x68,
  0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x67,0x69,0x74,0x68,0x75,0x62,0x2e,0x63,0x6f,
  0x6d,0x2f,0x70,0x62,0x65,0x6b,0x2f,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,0x73,
  0x2f,0x67,0x72,0x61,0x70,0x68,0x73,0x2f,0x63,0x6f,0x6e,0x74,0x72,0x69,0x62,0x75,
  0x74,0x6f,0x72,0x73,0x22,0x3e,0x20,0x74,0x68,0x65,0x20,0x51,0x4f,0x77,0x6e,0x4e,
  0x6f,0x74,0x65,0x73,0x20,0x63,0x6f,0x6e,0x74,0x72,0x69,0x62,0x75,0x74,0x6f,0x72,
  0x73,0x3c,0x2f,0x61,0x3e,0x3c,0x2f,0x70,0x3e,0xa,0x3c,0x70,0x3e,0x3c,0x61,0x20,
  0x68,0x72,0x65,0x66,0x3d,0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x77,0x77,
  0x77,0x2e,0x71,0x6f,0x77,0x6e,0x6e,0x6f,0x74,0x65,0x73,0x2e,0x6f,0x72,0x67,0x22,
  0x3e,0x77,0x77,0x77,0x2e,0x71,0x6f,0x77,0x6e,0x6e,0x6f,0x74,0x65,0x73,0x2e,0x6f,
  0x72,0x67,0x3c,0x2f,0x61,0x3e,0x3c,0x2f,0x70,0x3e,0xa,0x3c,0x70,0x3e,0xa,0x20,
  0x20,0x20,0x20,0x54,0x68,0x65,0x20,0x70,0x72,0x6f,0x67,0x72,0x61,0x6d,0x20,0x69,
  0x73,0x20,0x70,0x72,0x6f,0x76,0x69,0x64,0x65,0x64,0x20,0x41,0x53,0x20,0x49,0x53,
  0x20,0x77,0x69,0x74,0x68,0x20,0x4e,0x4f,0x20,0x57,0x41,0x52,0x52,0x41,0x4e,0x54,
  0x59,0x20,0x4f,0x46,0x20,0x41,0x4e,0x59,0x20,0x4b,0x49,0x4e,0x44,0x2c,0x20,0x49,
  0x4e,0x43,0x4c,0x55,0x44,0x49,0x4e,0x47,0x20,0x54,0x48,0x45,0xa,0x20,0x20,0x20,
  0x20,0x57,0x41,0x52,0x52,0x41,0x4e,0x54,0x59,0x20,0x4f,0x46,0x20,0x44,0x45,0x53,
  0x49,0x47,0x4e,0x2c,0x20,0x4d,0x45,0x52,0x43,0x48,0x41,0x4e,0x54,0x41,0x42,0x49,
  0x4c,0x49,0x54,0x59,0x20,0x41,0x4e,0x44,0x20,0x46,0x49,0x54,0x4e,0x45,0x53,0x53,
  0x20,0x46,0x4f,0x52,0x20,0x41,0x20,0x50,0x41,0x52,0x54,0x49,0x43,0x55,0x4c,0x41,
  0x52,0x20,0x50,0x55,0x52,0x50,0x4f,0x53,0x45,0x2e,0xa,0x3c,0x2f,0x70,0x3e,0xa,
  0x3c,0x70,0x3e,0xa,0x20,0x20,0x20,0x20,0x50,0x6c,0x65,0x61,0x73,0x65,0x20,0x72,
  0x65,0x70,0x6f,0x72,0x74,0x20,0x69,0x73,0x73,0x75,0x65,0x73,0x20,0x61,0x74,0x20,
  0x74,0x68,0x65,0xa,0x20,0x20,0x20,0x20,0x3c,0x61,0x20,0x68,0x72,0x65,0x66,0x3d,
  0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x67,0x69,0x74,0x68,0x75,0x62,0x2e,
  0x63,0x6f,0x6d,0x2f,0x70,0x62,0x65,0x6b,0x2f,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,
  0x65,0x73,0x2f,0x69,0x73,0x73,0x75,0x65,0x73,0x22,0x3e,0x51,0x4f,0x77,0x6e,0x4e,
  0x6f,0x74,0x65,0x73,0x20,0x69,0x73,0x73,0x75,0x65,0x20,0x70,0x61,0x67,0x65,0x3c,
  0x2f,0x61,0x3e,0x2e,0xa,0x3c,0x2f,0x70,0x3e,0xa,0x3c,0x2f,0x62,0x6f,0x64,0x79,
  0x3e,0x3c,0x2f,0x68,0x74,0x6d,0x6c,0x3e,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // html
  0x0,0x4,
  0x0,0x6,0xfb,0x3c,
  0x0,0x68,
  0x0,0x74,0x0,0x6d,0x0,0x6c,
    // about.html
  0x0,0xa,
  0xc,0x78,0x9,0xfc,
  0x0,0x61,
  0x0,0x62,0x0,0x6f,0x0,0x75,0x0,0x74,0x0,0x2e,0x0,0x68,0x0,0x74,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x92,0xf5,0x9b,0x80,0xf0,
  // :/html
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x92,0xf5,0x9b,0x80,0xf0,
  // :/html/about.html
  0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x92,0xf5,0x9b,0x80,0xf0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_texts)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_texts)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_texts)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_texts)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_texts)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_texts)(); }
   } dummy;
}

==> qownnotes-debug-24.11.1-1-x86_64.pkg.tar.zst: usr/src/debug/qownnotes/qownnotes-24.11.1/qrc_texts.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.15
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/qownnotes/src/qownnotes-24.11.1/html/about.html
  0x0,0x0,0x4,0x2a,
  0x3c,
  0x21,0x44,0x4f,0x43,0x54,0x59,0x50,0x45,0x20,0x48,0x54,0x4d,0x4c,0x20,0x50,0x55,
  0x42,0x4c,0x49,0x43,0x20,0x22,0x2d,0x2f,0x2f,0x57,0x33,0x43,0x2f,0x2f,0x44,0x54,
  0x44,0x20,0x48,0x54,0x4d,0x4c,0x20,0x34,0x2e,0x30,0x2f,0x2f,0x45,0x4e,0x22,0x20,
  0x22,0x68,0x74,0x74,0x70,0x3a,0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,
  0x72,0x67,0x2f,0x54,0x52,0x2f,0x52,0x45,0x43,0x2d,0x68,0x74,0x6d,0x6c,0x34,0x30,
  0x2f,0x73,0x74,0x72,0x69,0x63,0x74,0x2e,0x64,0x74,0x64,0x22,0x3e,0xa,0x3c,0x68,
  0x74,0x6d,0x6c,0x3e,0xa,0x3c,0x62,0x6f,0x64,0x79,0x3e,0xa,0x3c,0x70,0x3e,0x3c,
  0x73,0x74,0x72,0x6f,0x6e,0x67,0x3e,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,0x73,
  0x3c,0x2f,0x73,0x74,0x72,0x6f,0x6e,0x67,0x3e,0x20,0x2d,0x20,0x76,0x65,0x72,0x73,
  0x69,0x6f,0x6e,0x20,0x56,0x45,0x52,0x53,0x49,0x4f,0x4e,0x20,0x2d,0x20,0x52,0x45,
  0x4c,0x45,0x41,0x53,0x45,0x20,0x2d,0x20,0x62,0x75,0x69,0x6c,0x64,0x20,0x42,0x55,
  0x49,0x4c,0x44,0x5f,0x4e,0x55,0x4d,0x42,0x45,0x52,0x3c,0x2f,0x70,0x3e,0xa,0x3c,
  0x70,0x3e,0xa,0x20,0x20,0x20,0x20,0x50,0x6c,0x61,0x69,0x6e,0x2d,0x74,0x65,0x78,
  0x74,0x20,0x66,0x69,0x6c,0x65,0x20,0x6d,0x61,0x72,0x6b,0x64,0x6f,0x77,0x6e,0x20,
  0x6e,0x6f,0x74,0x65,0x20,0x74,0x61,0x6b,0x69,0x6e,0x67,0x20,0x77,0x69,0x74,0x68,
  0x20,0x4e,0x65,0x78,0x74,0x63,0x6c,0x6f,0x75,0x64,0x2f,0x6f,0x77,0x6e,0x43,0x6c,
  0x6f,0x75,0x64,0x20,0x69,0x6e,0x74,0x65,0x67,0x72,0x61,0x74,0x69,0x6f,0x6e,0x20,
  0x66,0x6f,0x72,0xa,0x20,0x20,0x20,0x20,0x47,0x4e,0x55,0x2f,0x4c,0x69,0x6e,0x75,
  0x78,0x2c,0x20,0x6d,0x61,0x63,0x4f,0x53,0x26,0x72,0x65,0x67,0x3b,0x20,0x61,0x6e,
  0x64,0x20,0x57,0x69,0x6e,0x64,0x6f,0x77,0x73,0x26,0x72,0x65,0x67,0x3b,0x20,0x28,
  0x69,0x74,0x20,0x69,0x73,0x20,0x77,0x72,0x69,0x74,0x74,0x65,0x6e,0x20,0x69,0x6e,
  0x20,0x43,0x2b,0x2b,0x2f,0x51,0x74,0x26,0x72,0x65,0x67,0x3b,0x29,0x2c,0xa,0x20,
  0x20,0x20,0x20,0x74,0x68,0x61,0x74,0x20,0x77,0x6f,0x72,0x6b,0x73,0x20,0x74,0x6f,
  0x67,0x65,0x74,0x68,0x65,0x72,0x20,0x77,0x69,0x74,0x68,0x20,0x74,0x68,0x65,0x20,
  0x6e,0x6f,0x74,0x65,0x73,0x20,0x61,0x70,0x70,0x6c,0x69,0x63,0x61,0x74,0x69,0x6f,
  0x6e,0x20,0x6f,0x66,0xa,0x20,0x20,0x20,0x20,0x3c,0x61,0x20,0x68,0x72,0x65,0x66,
  0x3d,0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x6e,0x65,0x78,0x74,0x63,0x6c,
  0x6f,0x75,0x64,0x2e,0x63,0x6f,0x6d,0x22,0x3e,0x4e,0x65,0x78,0x74,0x63,0x6c,0x6f,
  0x75,0x64,0x3c,0x2f,0x61,0x3e,0x20,0x61,0x6e,0x64,0xa,0x20,0x20,0x20,0x20,0x3c,
  0x61,0x20,0x68,0x72,0x65,0x66,0x3d,0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,
  0x6f,0x77,0x6e,0x63,0x6c,0x6f,0x75,0x64,0x2e,0x6f,0x72,0x67,0x22,0x3e,0x6f,0x77,
  0x6e,0x43,0x6c,0x6f,0x75,0x64,0x3c,0x2f,0x61,0x3e,0x2e,0xa,0x3c,0x2f,0x70,0x3e,
  0xa,0x3c,0x70,0x3e,0x42,0x75,0x69,0x6c,0x74,0x20,0x6f,0x6e,0x20,0x42,0x55,0x49,
  0x4c,0x44,0x5f,0x44,0x41,0x54,0x45,0x20,0x77,0x69,0x74,0x68,0x20,0x51,0x74,0x20,
  0x51,0x54,0x5f,0x56,0x45,0x52,0x53,0x49,0x4f,0x4e,0x5f,0x53,0x54,0x52,0x2e,0x3c,
  0x2f,0x70,0x3e,0xa,0x3c,0x70,0x3e,0x43,0x6f,0x70,0x79,0x72,0x69,0x67,0x68,0x74,
  0x20,0x32,0x30,0x31,0x34,0x2d,0x43,0x55,0x52,0x52,0x45,0x4e,0x54,0x5f,0x59,0x45,
  0x41,0x52,0x20,0x62,0x79,0x20,0x3c,0x61,0x20,0x68,0x72,0x65,0x66,0x3d,0x22,0x68,
  0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x67,0x69,0x74,0x68,0x75,0x62,0x2e,0x63,0x6f,
  0x6d,0x2f,0x70,0x62,0x65,0x6b,0x2f,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,0x73,
  0x2f,0x67,0x72,0x61,0x70,0x68,0x73,0x2f,0x63,0x6f,0x6e,0x74,0x72,0x69,0x62,0x75,
  0x74,0x6f,0x72,0x73,0x22,0x3e,0x20,0x74,0x68,0x65,0x20,0x51,0x4f,0x77,0x6e,0x4e,
  0x6f,0x74,0x65,0x73,0x20,0x63,0x6f,0x6e,0x74,0x72,0x69,0x62,0x75,0x74,0x6f,0x72,
  0x73,0x3c,0x2f,0x61,0x3e,0x3c,0x2f,0x70,0x3e,0xa,0x3c,0x70,0x3e,0x3c,0x61,0x20,
  0x68,0x72,0x65,0x66,0x3d,0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x77,0x77,
  0x77,0x2e,0x71,0x6f,0x77,0x6e,0x6e,0x6f,0x74,0x65,0x73,0x2e,0x6f,0x72,0x67,0x22,
  0x3e,0x77,0x77,0x77,0x2e,0x71,0x6f,0x77,0x6e,0x6e,0x6f,0x74,0x65,0x73,0x2e,0x6f,
  0x72,0x67,0x3c,0x2f,0x61,0x3e,0x3c,0x2f,0x70,0x3e,0xa,0x3c,0x70,0x3e,0xa,0x20,
  0x20,0x20,0x20,0x54,0x68,0x65,0x20,0x70,0x72,0x6f,0x67,0x72,0x61,0x6d,0x20,0x69,
  0x73,0x20,0x70,0x72,0x6f,0x76,0x69,0x64,0x65,0x64,0x20,0x41,0x53,0x20,0x49,0x53,
  0x20,0x77,0x69,0x74,0x68,0x20,0x4e,0x4f,0x20,0x57,0x41,0x52,0x52,0x41,0x4e,0x54,
  0x59,0x20,0x4f,0x46,0x20,0x41,0x4e,0x59,0x20,0x4b,0x49,0x4e,0x44,0x2c,0x20,0x49,
  0x4e,0x43,0x4c,0x55,0x44,0x49,0x4e,0x47,0x20,0x54,0x48,0x45,0xa,0x20,0x20,0x20,
  0x20,0x57,0x41,0x52,0x52,0x41,0x4e,0x54,0x59,0x20,0x4f,0x46,0x20,0x44,0x45,0x53,
  0x49,0x47,0x4e,0x2c,0x20,0x4d,0x45,0x52,0x43,0x48,0x41,0x4e,0x54,0x41,0x42,0x49,
  0x4c,0x49,0x54,0x59,0x20,0x41,0x4e,0x44,0x20,0x46,0x49,0x54,0x4e,0x45,0x53,0x53,
  0x20,0x46,0x4f,0x52,0x20,0x41,0x20,0x50,0x41,0x52,0x54,0x49,0x43,0x55,0x4c,0x41,
  0x52,0x20,0x50,0x55,0x52,0x50,0x4f,0x53,0x45,0x2e,0xa,0x3c,0x2f,0x70,0x3e,0xa,
  0x3c,0x70,0x3e,0xa,0x20,0x20,0x20,0x20,0x50,0x6c,0x65,0x61,0x73,0x65,0x20,0x72,
  0x65,0x70,0x6f,0x72,0x74,0x20,0x69,0x73,0x73,0x75,0x65,0x73,0x20,0x61,0x74,0x20,
  0x74,0x68,0x65,0xa,0x20,0x20,0x20,0x20,0x3c,0x61,0x20,0x68,0x72,0x65,0x66,0x3d,
  0x22,0x68,0x74,0x74,0x70,0x73,0x3a,0x2f,0x2f,0x67,0x69,0x74,0x68,0x75,0x62,0x2e,
  0x63,0x6f,0x6d,0x2f,0x70,0x62,0x65,0x6b,0x2f,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,
  0x65,0x73,0x2f,0x69,0x73,0x73,0x75,0x65,0x73,0x22,0x3e,0x51,0x4f,0x77,0x6e,0x4e,
  0x6f,0x74,0x65,0x73,0x20,0x69,0x73,0x73,0x75,0x65,0x20,0x70,0x61,0x67,0x65,0x3c,
  0x2f,0x61,0x3e,0x2e,0xa,0x3c,0x2f,0x70,0x3e,0xa,0x3c,0x2f,0x62,0x6f,0x64,0x79,
  0x3e,0x3c,0x2f,0x68,0x74,0x6d,0x6c,0x3e,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // html
  0x0,0x4,
  0x0,0x6,0xfb,0x3c,
  0x0,0x68,
  0x0,0x74,0x0,0x6d,0x0,0x6c,
    // about.html
  0x0,0xa,
  0xc,0x78,0x9,0xfc,
  0x0,0x61,
  0x0,0x62,0x0,0x6f,0x0,0x75,0x0,0x74,0x0,0x2e,0x0,0x68,0x0,0x74,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0xd,0xad,0x18,0x20,
  // :/html
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0xd,0xad,0x18,0x20,
  // :/html/about.html
  0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0xd,0xad,0x18,0x20,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_texts)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_texts)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_texts)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_texts)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_texts)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_texts)(); }
   } dummy;
}
